# RandomGeometricStructures
A collection of various function to draw and analyze random geometric structures (like pairings, tilings etc.)

An illustration can be found at: 

For pmaps package:
[Triangulations](https://colab.research.google.com/drive/1URQte3-X6Lau74B0JSjU7gkStO_-kx0O?usp=sharing )
